@@ -153,9 +153,3 @@ class Party(models.Model):
             self.id = uuid.uuid4()
         super(Party, self).save(*args, **kwargs)
 
-    class Meta:
-        ordering = ['timestamp']
-
-    def __str__(self):
-        return str(self.timestamp)
-
