@@ -1,4 +1,4 @@
-#   Copyright © 2020-2021 STiiiCK.
+#   Copyright © 2018-2021 STiiiCK.
 #
 #   This source code is licensed under the GPLv3 license found in the
 #   LICENSE file in the root directory of this source tree.
@@ -48,7 +48,7 @@ class StickProtocol():
         user.nextPreKeyId = data['nextPreKeyId']
         user.finishedRegistration = True
         user.save()
-        self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'])
+        self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'], chatId=data['oneTimeId'])
         Party.objects.create(user=user)
         Party.objects.create(user=user, individual=True)
 
@@ -476,10 +476,9 @@ class StickProtocol():
                        'identityKeyId': senderKey.identityKey.keyId, 'preKeyId': senderKey.preKey.keyId}
                 senderKeys.append(key)
             bundle['senderKeys'] = senderKeys
-            user.oneTimeId = uuid.uuid4()
             user.save()
             if not self.Device.objects.filter(user=user, deviceId=data['deviceId']).exists():
-                self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'])
+                self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'], chatId=uuid.uuid4())
             return {"bundle": bundle, "verify": True}
         else:
             return {"verify": False}
